@@ -50,7 +50,7 @@ var _ = Describe("iamserviceaccount filter", func() {
 				"sa/only-remote-2",
 				"kube-system/aws-node",
 			)
-			err := filter.SetDeleteFilter(context.TODO(), mockLister, true, cfg)
+			err := filter.SetDeleteFilter(context.Background(), mockLister, true, cfg)
 			Expect(err).NotTo(HaveOccurred())
 
 			included, excluded := filter.MatchAll(cfg.IAM.ServiceAccounts)
@@ -78,7 +78,7 @@ var _ = Describe("iamserviceaccount filter", func() {
 				"sa/only-remote-1",
 				"sa/only-remote-2",
 			)
-			err := filter.SetExcludeExistingFilter(context.TODO(), mockLister, clientSet, cfg.IAM.ServiceAccounts, true)
+			err := filter.SetExcludeExistingFilter(context.Background(), mockLister, clientSet, cfg.IAM.ServiceAccounts, true)
 			Expect(err).NotTo(HaveOccurred())
 
 			included, excluded := filter.MatchAll(cfg.IAM.ServiceAccounts)
@@ -117,7 +117,7 @@ var _ = Describe("iamserviceaccount filter", func() {
 			err = kubernetes.MaybeCreateServiceAccountOrUpdateMetadata(clientSet, sa2)
 			Expect(err).NotTo(HaveOccurred())
 
-			err = filter.SetExcludeExistingFilter(context.TODO(), mockLister, clientSet, cfg.IAM.ServiceAccounts, false)
+			err = filter.SetExcludeExistingFilter(context.Background(), mockLister, clientSet, cfg.IAM.ServiceAccounts, false)
 			Expect(err).NotTo(HaveOccurred())
 
 			included, excluded := filter.MatchAll(cfg.IAM.ServiceAccounts)
