@@ -6,8 +6,8 @@ import (
 	"os"
 	"time"
 
-	"github.com/aws/aws-sdk-go/aws"
-	awseks "github.com/aws/aws-sdk-go/service/eks"
+	"github.com/aws/aws-sdk-go-v2/aws"
+	ekstypes "github.com/aws/aws-sdk-go-v2/service/eks/types"
 
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
@@ -36,28 +36,28 @@ var _ = Describe("JSON Printer", func() {
 
 		Context("given a cluster struct and calling PrintObjWithKind", func() {
 			var (
-				cluster     *awseks.Cluster
+				cluster     *ekstypes.Cluster
 				err         error
 				actualBytes bytes.Buffer
 			)
 
 			BeforeEach(func() {
 				created := &time.Time{}
-				cluster = &awseks.Cluster{
+				cluster = &ekstypes.Cluster{
 					Name:      aws.String("test-cluster"),
-					Status:    aws.String(awseks.ClusterStatusActive),
+					Status:    ekstypes.ClusterStatusActive,
 					Arn:       aws.String("arn-12345678"),
 					CreatedAt: created,
-					ResourcesVpcConfig: &awseks.VpcConfigResponse{
+					ResourcesVpcConfig: &ekstypes.VpcConfigResponse{
 						VpcId:     aws.String("vpc-1234"),
-						SubnetIds: []*string{aws.String("sub1"), aws.String("sub2")},
+						SubnetIds: []string{"sub1", "sub2"},
 					},
 				}
 			})
 
 			JustBeforeEach(func() {
 				w := bufio.NewWriter(&actualBytes)
-				err = printer.PrintObjWithKind("clusters", []*awseks.Cluster{cluster}, w)
+				err = printer.PrintObjWithKind("clusters", []*ekstypes.Cluster{cluster}, w)
 				w.Flush()
 			})
 
@@ -81,32 +81,32 @@ var _ = Describe("JSON Printer", func() {
 
 		Context("given 2 cluster structs and calling PrintObjWithKind", func() {
 			var (
-				clusters    []*awseks.Cluster
+				clusters    []ekstypes.Cluster
 				err         error
 				actualBytes bytes.Buffer
 			)
 
 			BeforeEach(func() {
 				created := &time.Time{}
-				clusters = []*awseks.Cluster{
+				clusters = []ekstypes.Cluster{
 					{
 						Name:      aws.String("test-cluster-1"),
-						Status:    aws.String(awseks.ClusterStatusActive),
+						Status:    ekstypes.ClusterStatusActive,
 						Arn:       aws.String("arn-12345678"),
 						CreatedAt: created,
-						ResourcesVpcConfig: &awseks.VpcConfigResponse{
+						ResourcesVpcConfig: &ekstypes.VpcConfigResponse{
 							VpcId:     aws.String("vpc-1234"),
-							SubnetIds: []*string{aws.String("sub1"), aws.String("sub2")},
+							SubnetIds: []string{"sub1", "sub2"},
 						},
 					},
 					{
 						Name:      aws.String("test-cluster-2"),
-						Status:    aws.String(awseks.ClusterStatusActive),
+						Status:    ekstypes.ClusterStatusActive,
 						Arn:       aws.String("arn-87654321"),
 						CreatedAt: created,
-						ResourcesVpcConfig: &awseks.VpcConfigResponse{
+						ResourcesVpcConfig: &ekstypes.VpcConfigResponse{
 							VpcId:     aws.String("vpc-1234"),
-							SubnetIds: []*string{aws.String("sub1"), aws.String("sub2")},
+							SubnetIds: []string{"sub1", "sub2"},
 						},
 					},
 				}
@@ -138,7 +138,7 @@ var _ = Describe("JSON Printer", func() {
 
 		Context("given an empty cluster list and calling PrintObjWithKind", func() {
 			var (
-				clusters    []*awseks.Cluster
+				clusters    []*ekstypes.Cluster
 				err         error
 				actualBytes bytes.Buffer
 			)
